@@ -14,16 +14,16 @@ from yt_dlp.cookies import (
 
 
 class Logger:
-    def debug(self, message):
+    def debug(self, message, *args, **kwargs):
         print(f'[verbose] {message}')
 
-    def info(self, message):
+    def info(self, message, *args, **kwargs):
         print(message)
 
-    def warning(self, message, only_once=False):
+    def warning(self, message, *args, **kwargs):
         self.error(message)
 
-    def error(self, message):
+    def error(self, message, *args, **kwargs):
         raise Exception(message)
 
 
