@@ -795,12 +795,14 @@ class BiliIntlBaseIE(InfoExtractor):
 
     def _get_subtitles(self, *, ep_id=None, aid=None):
         sub_json = self._call_api(
-            '/web/v2/subtitle', ep_id or aid, note='Downloading subtitles list',
-            errnote='Unable to download subtitles list', query=filter_dict({
+            '/web/v2/subtitle', ep_id or aid, fatal=False,
+            note='Downloading subtitles list', errnote='Unable to download subtitles list',
+            query=filter_dict({
                 'platform': 'web',
+                's_locale': 'en_US',
                 'episode_id': ep_id,
                 'aid': aid,
-            }))
+            })) or {}
         subtitles = {}
         for sub in sub_json.get('subtitles') or []:
             sub_url = sub.get('url')
