@@ -1,13 +1,9 @@
 import codecs
-import re
 import json
+import re
 
 from .common import InfoExtractor
-from ..compat import (
-    compat_chr,
-    compat_ord,
-    compat_urllib_parse_unquote,
-)
+from ..compat import compat_ord, compat_urllib_parse_unquote
 from ..utils import (
     ExtractorError,
     float_or_none,
@@ -16,8 +12,8 @@ from ..utils import (
     multipart_encode,
     parse_duration,
     random_birthday,
-    urljoin,
     try_get,
+    urljoin,
 )
 
 
@@ -144,7 +140,7 @@ class CDAIE(InfoExtractor):
             b = []
             for c in a:
                 f = compat_ord(c)
-                b.append(compat_chr(33 + (f + 14) % 94) if 33 <= f <= 126 else compat_chr(f))
+                b.append(chr(33 + (f + 14) % 94) if 33 <= f <= 126 else chr(f))
             a = ''.join(b)
             a = a.replace('.cda.mp4', '')
             for p in ('.2cda.pl', '.3cda.pl'):
