@@ -34,7 +34,7 @@ class LineLiveBaseIE(InfoExtractor):
             'timestamp': int_or_none(item.get('createdAt')),
             'channel': channel.get('name'),
             'channel_id': channel_id,
-            'channel_url': format_field(channel_id, template='https://live.line.me/channels/%s'),
+            'channel_url': format_field(channel_id, None, 'https://live.line.me/channels/%s'),
             'duration': int_or_none(item.get('archiveDuration')),
             'view_count': int_or_none(item.get('viewerCount')),
             'comment_count': int_or_none(item.get('chatCount')),
