@@ -14,6 +14,7 @@ from ..utils import (
 
 class MainStreamingIE(InfoExtractor):
     _VALID_URL = r'https?://(?:webtools-?)?(?P<host>[A-Za-z0-9-]*\.msvdn.net)/(?:embed|amp_embed|content)/(?P<id>\w+)'
+    _EMBED_REGEX = [rf'<iframe[^>]+?src=["\']?(?P<url>{_VALID_URL})["\']?']
     IE_DESC = 'MainStreaming Player'
 
     _TESTS = [
@@ -102,13 +103,6 @@ class MainStreamingIE(InfoExtractor):
         }
     ]
 
-    @staticmethod
-    def _extract_urls(webpage):
-        mobj = re.findall(
-            r'<iframe[^>]+?src=["\']?(?P<url>%s)["\']?' % MainStreamingIE._VALID_URL, webpage)
-        if mobj:
-            return [group[0] for group in mobj]
-
     def _playlist_entries(self, host, playlist_content):
         for entry in playlist_content:
             content_id = entry.get('contentID')
