@@ -310,6 +310,7 @@ class TVPEmbedIE(InfoExtractor):
                 =)
         (?P<id>\d+)
     '''
+    _EMBED_REGEX = [rf'(?x)<iframe[^>]+?src=(["\'])(?P<url>{_VALID_URL[4:]})']
 
     _TESTS = [{
         'url': 'tvp:194536',
@@ -340,12 +341,6 @@ class TVPEmbedIE(InfoExtractor):
         'only_matching': True,
     }]
 
-    @staticmethod
-    def _extract_urls(webpage, **kw):
-        return [m.group('embed') for m in re.finditer(
-            r'(?x)<iframe[^>]+?src=(["\'])(?P<embed>%s)' % TVPEmbedIE._VALID_URL[4:],
-            webpage)]
-
     def _real_extract(self, url):
         video_id = self._match_id(url)
 
